searchData={"content_type":"text/markdown","items":[{"doc":"Module for working with \"result\" tuples. Provides helpers for wrapping,\nunwrapping, and transforming result tuples.\n\nAn opinionated stance on what constitutes a \"result\" tuple is taken here. A\nresult tuple is a tuple of the form `{:ok, value}` or `{:error, value}` and\nnothing else.\n\nThese helpers are most useful in pipelines.","ref":"ExResult.html","title":"ExResult","type":"module"},{"doc":"Wraps a value in an `:error` tuple.\n\nIf the value is already an `:error` tuple, it will be returned as-is.\n\n#","ref":"ExResult.html#error/1","title":"ExResult.error/1","type":"function"},{"doc":"iex> error(:foo)\n    {:error, :foo}\n\n    iex> error({:error, :foo})\n    {:error, :foo}","ref":"ExResult.html#error/1-examples","title":"Examples - ExResult.error/1","type":"function"},{"doc":"Checks if a value is an `:error` tuple.\n\n#","ref":"ExResult.html#error?/1","title":"ExResult.error?/1","type":"function"},{"doc":"iex> error?({:ok, 1})\n    false\n\n    iex> error?({:error, :foo})\n    true\n\n    iex> error?(1)\n    false","ref":"ExResult.html#error?/1-examples","title":"Examples - ExResult.error?/1","type":"function"},{"doc":"Guard to check if a value is a result tuple.\n\nA result tuple is a tuple of the form `{:ok, value}` or `{:error, value}` and\nnothing else.\n\n#","ref":"ExResult.html#is_result/1","title":"ExResult.is_result/1","type":"macro"},{"doc":"iex> is_result({:ok, 1})\n    true\n\n    iex> is_result({:error, :foo})\n    true\n\n    iex> is_result(1)\n    false","ref":"ExResult.html#is_result/1-examples","title":"Examples - ExResult.is_result/1","type":"macro"},{"doc":"Wraps a value in an `:ok` tuple.\n\nIf the value is already an `:ok` tuple, it will be returned as-is.\n\n#","ref":"ExResult.html#ok/1","title":"ExResult.ok/1","type":"function"},{"doc":"iex> ok(1)\n    {:ok, 1}\n\n    iex> ok({:ok, 1})\n    {:ok, 1}","ref":"ExResult.html#ok/1-examples","title":"Examples - ExResult.ok/1","type":"function"},{"doc":"Checks if a value is an `:ok` tuple.\n\n#","ref":"ExResult.html#ok?/1","title":"ExResult.ok?/1","type":"function"},{"doc":"iex> ok?({:ok, 1})\n    true\n\n    iex> ok?({:error, :foo})\n    false\n\n    iex> ok?(1)\n    false","ref":"ExResult.html#ok?/1-examples","title":"Examples - ExResult.ok?/1","type":"function"},{"doc":"Unwraps a value from an `:ok` tuple or returns an `:error` tuple as-is.\n\nIf the value is not an `:ok` or `:error` tuple, an error will be raised.\n\n#","ref":"ExResult.html#unwrap/1","title":"ExResult.unwrap/1","type":"function"},{"doc":"iex> unwrap({:ok, 1})\n    1\n\n    iex> unwrap({:error, :foo})\n    {:error, :foo}\n\n    iex> unwrap(1)\n    ** (ArgumentError) 1st argument: not an :ok or :error result tuple","ref":"ExResult.html#unwrap/1-examples","title":"Examples - ExResult.unwrap/1","type":"function"},{"doc":"Unwraps a value from an `:ok` tuple or raises if not an `:ok` tuple.\n\n#","ref":"ExResult.html#unwrap!/1","title":"ExResult.unwrap!/1","type":"function"},{"doc":"iex> unwrap!({:ok, 1})\n    1\n\n    iex> unwrap!({:error, :foo})\n    ** (ArgumentError) 1st argument: not an :ok result tuple\n\n    iex> unwrap!(1)\n    ** (ArgumentError) 1st argument: not an :ok result tuple","ref":"ExResult.html#unwrap!/1-examples","title":"Examples - ExResult.unwrap!/1","type":"function"},{"doc":"Unwraps the \"value\" from an `:ok` tuple and executes a transform on it or\nreturns an `:error` tuple as-is.\n\nIf the value is not an `:ok` or `:error` tuple, an error will be raised.\n\n#","ref":"ExResult.html#unwrap_and_update/2","title":"ExResult.unwrap_and_update/2","type":"function"},{"doc":"iex> unwrap_and_update({:ok, 1}, &(&1 * 2))\n    2\n\n    iex> unwrap_and_update({:error, :foo}, &(&1 * 2))\n    {:error, :foo}\n\n    iex> unwrap_and_update(1, &(&1 * 2))\n    ** (ArgumentError) 1st argument: not an :ok or :error result tuple","ref":"ExResult.html#unwrap_and_update/2-examples","title":"Examples - ExResult.unwrap_and_update/2","type":"function"},{"doc":"Executes a transform on the \"value\" of an `:ok` tuple or raises if not an\n`:ok` tuple.\n\n#","ref":"ExResult.html#unwrap_and_update!/2","title":"ExResult.unwrap_and_update!/2","type":"function"},{"doc":"iex> unwrap_and_update!({:ok, 1}, &(&1 * 2))\n    2\n\n    iex> unwrap_and_update!({:error, :foo}, &(&1 * 2))\n    ** (ArgumentError) 1st argument: not an :ok result tuple\n\n    iex> unwrap_and_update!(1, &(&1 * 2))\n    ** (ArgumentError) 1st argument: not an :ok result tuple","ref":"ExResult.html#unwrap_and_update!/2-examples","title":"Examples - ExResult.unwrap_and_update!/2","type":"function"},{"doc":"Updates the \"value\" of an `:ok` tuple or returns an :error tuple as-is.\n\nIf the value is not an `:ok` or `:error` tuple, an error will be raised.\n\n#","ref":"ExResult.html#update/2","title":"ExResult.update/2","type":"function"},{"doc":"iex> update({:ok, 1}, &(&1 + 1))\n    {:ok, 2}\n\n    iex> update({:error, :foo}, &(&1 + 1))\n    {:error, :foo}\n\n    iex> update(1, &(&1 + 1))\n    ** (ArgumentError) 1st argument: not an :ok or :error result tuple","ref":"ExResult.html#update/2-examples","title":"Examples - ExResult.update/2","type":"function"},{"doc":"Updates the \"value\" of an `:ok` tuple or raises if not an `:ok` tuple.\n\n#","ref":"ExResult.html#update!/2","title":"ExResult.update!/2","type":"function"},{"doc":"iex> update!({:ok, 1}, &(&1 + 1))\n    {:ok, 2}\n\n    iex> update!({:error, :foo}, &(&1 + 1))\n    ** (ArgumentError) 1st argument: not an :ok result tuple\n\n    iex> update!(1, &(&1 + 1))\n    ** (ArgumentError) 1st argument: not an :ok result tuple","ref":"ExResult.html#update!/2-examples","title":"Examples - ExResult.update!/2","type":"function"},{"doc":"","ref":"ExResult.html#t:error_result/0","title":"ExResult.error_result/0","type":"type"},{"doc":"","ref":"ExResult.html#t:ok_result/0","title":"ExResult.ok_result/0","type":"type"},{"doc":"","ref":"ExResult.html#t:result/0","title":"ExResult.result/0","type":"type"},{"doc":"","ref":"ExResult.html#t:update_fn/0","title":"ExResult.update_fn/0","type":"type"}]}